@@ -9,21 +9,15 @@ Main API:
 - ``ijson.items``: iterator returning Python objects found under a specified prefix,
   see ``ijson.common.items`` for docs.
 
-Top-level ``ijson`` module tries to automatically find and import a suitable
-parsing backend. You can also explicitly import a required backend from
-``ijson.backends``.
+Top-level ``ijson`` module exposes method from the pure Python backend. There's
+also two other backends using the C library yajl in ``ijson.backends`` that have
+the same API and are faster under CPython.
 '''
-
 from ijson.common import JSONError, IncompleteJSONError, ObjectBuilder
-from ijson.backends import YAJLImportError
+import ijson.backends.python as backend
 
-try:
-    import ijson.backends.yajl2 as backend
-except YAJLImportError:
-    try:
-        import ijson.backends.yajl as backend
-    except YAJLImportError:
-        import ijson.backends.python as backend
+
+__version__ = '2.4'
 
 
 basic_parse = backend.basic_parse
